# Attention please!

Un avertissement a été généré lors de la création d'un nouvel item.

- Ceci peut indiquer qe vous utiliser un plugin qui a été créé pour une version antérieure d'OpenSesame.
- Les avertissements peuvent générer des rapports de bug ("Oops, I did it again ..."); vous pouvez désactiver l'extension `bug_report`.
- Des informations détaillées sur l'avertissement sont disponibles dans la fenêtre de débogage.
